@@ -7,14 +7,15 @@ from gtest.utils.opt_parser import OptionParser
 from gtest.utils.output import Output
 from gtest.utils.logger import logger
 from gtest.exceptions import BaseException
+from gtest.utils.file import log_traceback
 import sys
 
 
 class GTest(object):
-    version = '0.1.3'
+    version = '0.1.4'
 
     def __init__(self, path, options):
-        self.opt = Options(path, options)
+        self.opt = Options(path, options, self.version)
         self.path = self.opt.run_path
         self.output = Output(self.opt)
 
@@ -29,9 +30,12 @@ class GTest(object):
             if isinstance(e, BaseException):
                 logger.debug("正常退出")
             else:
-                logger.debug('异常退出，原因: {}'.format(str(e)))
+                import traceback
+                exception_info = str(e)
+                logger.debug('异常退出，原因: {}'.format(exception_info))
+                traceback_info = traceback.format_exc()
+                log_traceback(exception_info, traceback_info)
                 if self.opt.track_error:
-                    import traceback
                     traceback.print_exc()
 
 
