@@ -96,8 +96,8 @@ class BaseOptions(object):
 
 class Options(BaseOptions):
     """选项解析类"""
-    def __init__(self, path, options):
-        self.selection = {'select': None, 'exclude': None, 'tag': None}  # 筛选条件
+    def __init__(self, path, options, version):
+        self.version = version
         for option, value in self.options.items():  # 先保存baseoption中保存的默认值
             setattr(self, option, value[1])
         if options and 'option' in options:  # 先查找命令行参数中是否有指定option文件
