@@ -30,6 +30,15 @@ class OptionParser(object):
                                  if key.startswith('v_')}
 
     def parse(self, args):
+        try:
+            path, opts = self._parse(args)
+        except Exception as e:
+            exit()
+        else:
+            return path, opts
+
+
+    def _parse(self, args):
         """解析命令行参数"""
         '''处理开头的必要的参数'''
         if args:
